Sold Items by Branch Report

Code | Product | Branch | Quantity | Total
09 | Blusa Balonê com Bordado nas Costas | Moda Stoq | 1 | $150.00
08 | Blusa Frente-Única com Pregas | Moda Stoq | 1 | $220.00
07 | Casaco Vilan | Moda Stoq | 1 | $503.00
06 | Calça Brigilda | Moda Stoq | 1 | $438.00
05 | Calça Jeans com Bolso Traseiro | Moda Stoq | 1 | $189.00
04 | Chinelo de Dedo | Moda Stoq | 1 | $79.00
03 | Camiseta Tinturada Xcuba Comp | Moda Stoq | 1 | $89.00
02 | Shorts com Costuras | Moda Stoq | 1 | $198.00
01 | Bermuda Sarja | Moda Stoq | 1 | $149.00
|  |  | 9 | $2015.00